﻿using System.Windows;
using PSFinancials.TaskManager600.Services;
using PSFinancials.TaskManager600.ViewModels;
using PSFinancials.TaskManager600.Views;

namespace PSFinancials.TaskManager600
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        #region Members

        private static ServiceProvider _Services = new ServiceProvider();
        private static string _user = string.Empty;
        private static string _database = string.Empty;
        private static string _password = string.Empty;
        private static string _company = string.Empty;
        private static string _server = string.Empty;

        #endregion

        #region Properties

        /// <summary>
        /// Gets the services registered with the application.
        /// </summary>
        /// <remarks>
        /// This service collection is made static so that any class in the application (i.e. the view models) can access the same set of services. The App class is a good place to hold
        /// onto this, or if a base class is being used for the view models then this can be a better location (it can be made 'protected' to ensure only view models can access the services)
        /// 
        /// It's worth noting that storing and accessing services in a static location like this can lead to becoming too dependant on using services. One of the bad practices associated
        /// with this technique is that it is difficult to tell which class depends on which service (for example, which view models are going to use the IWindowService service?). A preferable
        /// solution is to have classes contain properties (or constructor parameters) so that the required services can be passed to the class directly rather than having the class 'pull' the
        /// services from an external location like this.
        /// 
        /// Some frameworks (such as Prism, Unity or MEF) provide sets of classes which assist in removing the need to provide a global list of services.
        /// </remarks>
        public static ServiceProvider Services
        {
            get { return _Services; }
        }

        #endregion

        #region Methods

        /// <summary>
        /// Handles the application starting up.
        /// </summary>
        protected override void OnStartup(StartupEventArgs e)
        {
            // register common services
            Services.RegisterService<IWindowService>(new WpfWindowService());
            base.OnStartup(e);

            Current.ShutdownMode = ShutdownMode.OnExplicitShutdown;

            var windowService = Services.GetService<IWindowService>();

            var mainWindow = new MainWindow { DataContext = new MainViewModel() };
            Current.ShutdownMode = ShutdownMode.OnMainWindowClose;
            Current.MainWindow = mainWindow;
            mainWindow.Show();
        }

        #endregion
    }
}
