﻿using System.Windows;

namespace PSFinancials.TaskManager600
{
    /// <summary>
    /// Common interface to be implemented by classes that can display windows.
    /// </summary>
    public interface IWindowService
    {
        /// <summary>
        /// Displays a window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <param name="context">The window's data context.</param>
        void Show<T>(object context) where T : Window, new();

        /// <summary>
        /// Displays a window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        void Show<T>() where T : Window, new();

        /// <summary>
        /// Displays a modal window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <param name="context">The window's data context.</param>
        /// <returns>The dialog result.</returns>
        bool? ShowDialog<T>(object context) where T : Window, new();

        /// <summary>
        /// Displays a modal window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <returns>The dialog result.</returns>
        bool? ShowDialog<T>() where T : Window, new();
    }
}
