﻿using System.Windows;

namespace PSFinancials.TaskManager600.Services
{
    class WpfWindowService : IWindowService
    {
        #region Functions

        /// <summary>
        /// Creates a new window.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <returns>The new window.</returns>
        private static Window CreateWindow<T>() where T : Window, new()
        {
            // as well as creating a new instance of the window, we need to set its Owner to the main application window,
            // so that we closing the main window will close all of the child windows (otherwise, the application will continue
            // to run until the user goes through each window and closes them all separately)
            var window = new T();

            if (Application.Current.MainWindow != window)
                window.Owner = Application.Current.MainWindow;
            return window;
        }

        /// <summary>
        /// Displays a window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <param name="context">The window's data context.</param>
        public void Show<T>(object context) where T : Window, new()
        {
            var window = CreateWindow<T>();
            window.DataContext = context;
            window.Show();
        }

        /// <summary>
        /// Displays a window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        public void Show<T>() where T : Window, new()
        {
            var window = CreateWindow<T>();
            window.Show();
        }

        /// <summary>
        /// Displays a modal window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <param name="context">The window's data context.</param>
        /// <returns>The dialog result.</returns>
        public bool? ShowDialog<T>(object context) where T : Window, new()
        {
            var window = CreateWindow<T>();
            window.DataContext = context;
            return window.ShowDialog();
        }

        /// <summary>
        /// Displays a modal window to the user.
        /// </summary>
        /// <typeparam name="T">The type of window to show.</typeparam>
        /// <returns>The dialog result.</returns>
        public bool? ShowDialog<T>() where T : Window, new()
        {
            var window = CreateWindow<T>();
            return window.ShowDialog();
        }

        #endregion
    }
}
